Learn R Programming

NMTox (version 0.1.0)

Isoplot: Create plot(s) of the observations, the sample means and the fitted isotonic regression curve

Description

This function creates plot(s) of the observations, the sample means and the fitted isotonic regression curve for one or more nanomaterials simultaneously

Usage

Isoplot(data.nm, data.control, id, nano, response, dose, end, end.cat,
  unit, unit.cat, dose.type=c("dose","log"), type = c("continuous",
  "ordinal"), control.opt=c("same","all"), add.curve = TRUE, vars, nrow=1,
  ncol=1, xlabel="Dose", ylabel="Response")

Value

This function produces plot(s) consisting of observation data points, sample mean for each dose and fitted isotonic regression curve

Arguments

data.nm

Data containing the result of toxicity study

data.control

Data of control values

id

Identifier of the experiment

nano

Name of the nanomaterial

response

Response (endpoint value)

dose

Dose or concentration

end

Toxicity endpoint

end.cat

Specific toxicity endpoint of interest

unit

Unit of measurement of the dose

unit.cat

Specific unit of measurement of the dose

dose.type

Type of the dose to be plotted ("dose" for dose and "log" for log(dose))

type

Type of the dose (continuous or ordinal)

control.opt

Option for the control doses if unit and unit.cat are specified. If only control doses with the same unit of measurement as the non-control ones are included, then specify "same" in the control.opt. If all control doses with any units of measurement are included, then specify "all".

add.curve

Adding curve to the plot

vars

Variable(s) used to subset the data

nrow

Number of row in the plotting space

ncol

Number of column in the plotting space

xlabel

Label for x-axis

ylabel

Label for y-axis

Details

  • This function performs data exploration for each nanomaterial in the dataset (or for each subset of data). The different types of nanomaterials are identified by their names. Therefore, if some control values are named differently (see: geninvitro dataset and the Examples), a separate dataset containing only these values first needs to be created. Controls in the new dataset can be linked to the non-control observations belonging to the same experiment through the identifier of the experiment (the linking is performed inside this function). In this situation, it is necessary to have an indicator that can identify different experiments (such as experiment ID).

  • If all controls in the dataset are named according to the related nanomaterial names, data.control and id do not need to be specified.

  • If doses used in the experiment are all measured in the same unit of measurement, then specify "same" in control.opt.

  • Dose-response plot can also be generated for subsets of data in each nanomaterial by specifying the variables used to split the data in vars.

References

Lin D., Pramana, S., Verbeke, T., and Shkedy, Z. (2015). IsoGene: Order-Restricted Inference for Microarray Experiments. R package version 1.0-24. https://CRAN.R-project.org/package=IsoGene

Lin D., Shkedy Z., Yekutieli D., Amaratunga D., and Bijnens, L. (editors). (2012) Modeling Doseresponse Microarray Data in Early Drug Development Experiments Using R. Springer.

Examples

Run this code
# Example 1:
# Create a dataset containing controls (which are named differently)
# from geninvitro dataset:
controldata<-SubsetData(data=geninvitro, x="name", x.cat=c("control", "Control",
             "medium", "medium + BSA", "untreated"))

# Exclude controls (which are named differently) from geninvitro dataset:
invitrodata<-SubsetData(data=geninvitro, x="name", x.cat=c("control", "Control",
             "medium", "medium + BSA", "untreated"), include=FALSE)
#
# Generate dose-response plots for geninvitro, with DNA STRAND BREAKS
# as the endpoint, concentrations measured in "ug/cm2"
# and control doses measured in any units of measurement:
#
Isoplot(data.nm=invitrodata, data.control=controldata, id="experimentID",
        nano="name", response="value", dose="concentration", end="endpoint",
        end.cat="DNA STRAND BREAKS", unit="concentration_unit", unit.cat="ug/cm2",
        dose.type="dose", control.opt="all")

# Example 2:
# Split geninvitro data according to the cell type, method, study provider and
# unit of the concentration and generate dose-response plot for each subset
# of data with DNA STRAND BREAKS as the endpoint:
#
Isoplot(data.nm=invitrodata, data.control=controldata, id="experimentID",
        nano="name", response="value", dose="concentration", end="endpoint",
        end.cat="DNA STRAND BREAKS",  dose.type="dose",
        vars=c("celltype","method","studyprovider","concentration_unit"),
        nrow=2, ncol=2)

Run the code above in your browser using DataLab