Learn R Programming

NMTox (version 0.1.0)

geninvitro: Genetic toxicity in vitro dataset

Description

This dataset contains the result of genetic toxicity in vitro studies and variables related to the experiments for several different nanomaterials.

Usage

data(geninvitro)

Arguments

Format

A data frame with columns:

  • name: Project-assigned name of the nanomaterial

  • publicname: A widely accepted unique identifier

  • supplier: Supplier/project where the data is originated from

  • experimentID: Identifier of the experiment

  • method: Method/assay used in the experiment

  • studyprovider: Study provider

  • endpoint: Toxicity endpoint measure

  • value: Endpoint value

  • unit: Unit of the endpoint

  • celltype: Type of the cell used in the experiment

  • treatment: Indicator of the treatment

  • exptimeunit: Unit of measurement of the exposure time

  • exptime: Exposure time

  • concentration_unit: Unit of measurement of the concentration in variable concentration

  • concentration: Concentration of the nanomaterial

  • concentration_ml_unit: Unit of measurement of the concentration in variable concentration_ml

  • concentration_ml: Concentration of the nanomaterial in amount per ml

Details

Since some of the controls in geninvitro dataset are not named according to the nanomaterial names, the experiment identifier (ID) can be used to identify which control values are related to which nanomaterial.

Examples

Run this code
data(geninvitro)

Run the code above in your browser using DataLab